package com.javaseleniumtemplate.pages;

import com.javaseleniumtemplate.bases.PageBase;
import org.openqa.selenium.By;
import org.openqa.selenium.Keys;
import org.openqa.selenium.interactions.Actions;
import org.testng.Assert;

public class CategoriaEmbalagemPage extends PageBase {

    By botaoMenu = By.xpath("//div[@class='bars']");
    By campoPesquisar = By.xpath("//section[@class='zh-container-search-menu']//input[@type='text']");
    By opcaoTelaCategoriaEmbalagens = By.xpath("//span[text() = 'Categoria de Embalagens']");

    By botaoAdicionar = By.xpath("//div[@class=\"zh-footer-center\"]");
    By botaoSalvar = By.xpath("//div[@class=\"zh-footer-right\"]");
    By botaoExcluir = By.xpath("//div[@class=\"zh-footer-center\"]");

    By campoCodigo = By.id("CDCATEMBALAG");
    By campoNome = By.id("NMCATEMBALAG");
    By mensagemObrigatorioCodigo = By.xpath("//div[@data-zh-id=\"932039233211315236995\"]//div[@class=\"zh-validation\"]/span");
    By mensagemObrigatorioNome = By.xpath("//div[@data-zh-id=\"93203923317775255997\"]//div[@class=\"zh-validation\"]/span");

    By checkBoxCategoria1 = By.xpath("//div[@id=\"grid-9320392325592474642427\"]//div[@class=\"body-content\"]/div[1]/div[1]//span[@data-ng-if=\"!row.__group\"]");
    By nomeCategoria1 = By.xpath("//div[@id=\"grid-9320392325592474642427\"]//div[@class=\"body-content\"]/div[1]/div[3]/span");

    By checkBoxCategoria = By.xpath("//div[@id=\"grid-9320392325592474642427\"]//div[@class=\"body-content\"]/div[4]/div[1]/span");
    By codigoCategoria = By.xpath("//div[@id=\"grid-9320392325592474642427\"]//div[@class=\"body-content\"]/div[4]/div[2]/span");
    By nomeCategoria = By.xpath("//div[@id=\"grid-9320392325592474642427\"]//div[@class=\"body-content\"]/div[4]/div[3]/span");

    By mensagemCantoSuperiorDireito = By.xpath("//*[@class=\"zh-notification-messages\"]//span[@class=\"notification-message-text\"]");
    By mensagemAlerta = By.xpath("//section[@class=\"zh-container-alert\"]//div[@class=\"zh-alert-scroll\"]/p");
    By botaoSim = By.xpath("//section[@class=\"zh-container-alert\"]//button[@data-zh-id=\"zh-footer-alert-button-0\"]");
    By botaoOkAlerta = By.xpath("//section[@class=\"zh-container-alert\"]//button[@class=\"zh-alert-button\"]");

    public void acessarTela() {
        tempoParaAguardarTelaInicial();
        waitForElement(botaoMenu);
        click(botaoMenu);
        sendKeys(campoPesquisar, "Categoria de Embalagens");
        click(opcaoTelaCategoriaEmbalagens);
    }

    public void adicionarCategoria() {
        click(botaoAdicionar);
        sendKeys(campoCodigo, "4");
        sendKeys(campoNome, "QUATERNÁRIA");
        click(botaoSalvar);

        //dados encontrados da categoria adicionada
        String codigo = getText(codigoCategoria);
        String nome = getText(nomeCategoria);

        Assert.assertEquals(codigo, "00004", "Verificação do código da categoria adicionada");
        Assert.assertEquals(nome, "QUATERNÁRIA", "Verificação do nome da categoria adicionada");
    }

    public void tentarAdicionarCodigoExistente() {
        click(botaoAdicionar);
        sendKeys(campoCodigo, "3");
        sendKeys(campoNome, "QUATERNÁRIA");
        click(botaoSalvar);

        //mensagem alertando que o registro já existe
        String mensagem = getText(mensagemAlerta);
        String mensagemEsperada = "Registro já existe.";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificar se após tentar adicionar uma categoria com código já existente, é exibida uma mensagem na tela informando que o registro já existe");
        click(botaoOkAlerta);
    }

    public void editarCategoria() {
        tempo();
        tempo();
        Actions actions = new Actions(driver);
        actions.click(driver.findElement(nomeCategoria)).build().perform();
        tempo();
        actions.sendKeys(Keys.BACK_SPACE).build().perform();
        tempo();
        actions.sendKeys("QUINTERNÁRIA").build().perform();
        tempo();
        actions.sendKeys(Keys.ENTER).build().perform();

        click(botaoSalvar);
        tempo();
        String nome = getText(nomeCategoria);
        Assert.assertEquals(nome, "QUINTERNÁRIA", "Verificação do nome da categoria após a edição");
    }

    public void excluirCategoria() {
        click(checkBoxCategoria);
        click(botaoExcluir);
        tempo();

        //mensagem de alerta da exclusão
        String mensagem = getText(mensagemAlerta);
        String mensagemEsperada = "Deletar o(s) registro(s)?";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem de alerta da exclusão da categoria");
        click(botaoSim);

        //mensagem de excluído com sucesso
        mensagem = getText(mensagemCantoSuperiorDireito);
        mensagemEsperada = "Excluído com sucesso.";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem da categoria excluída com sucesso");
    }

    public void camposObrigatorios() {
        click(botaoAdicionar);
        tempo();
        click(botaoSalvar);

        //mensagem de campos obrigatório encontada nos campos
        String codigo = getText(mensagemObrigatorioCodigo);
        String nome = getText(mensagemObrigatorioNome);

        String mensagemEsperada = "Campo obrigatório";
        Assert.assertEquals(codigo, mensagemEsperada, "Verificação da mensagem de campo obrigatório, no campo de código");
        Assert.assertEquals(nome, mensagemEsperada, "Verificação da mensagem de campo obrigatório, no campo do nome");
    }

    public void tentarExcluirCategoriaComRegistrosFilhos() {
        click(checkBoxCategoria1);
        click(botaoExcluir);

        //mensagem de alerta da exclusão
        String mensagem = getText(mensagemAlerta);
        String mensagemEsperada = "Deletar o(s) registro(s)?";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem de alerta da exclusão da categoria");
        click(botaoSim);

        //mensagem de alerta informando que a exclusão não é permitida, pois existem registros filhos
        mensagem = getText(mensagemAlerta);
        mensagemEsperada = "Exclusão não permitida! O registro possui registros filhos.";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem de alerta da não permissaõ da exclusão, demido à categoria possuir registros filhos");
        click(botaoOkAlerta);

        String nomeEncontrado = getText(nomeCategoria1);
        String nomeEsperado = "PRIMÁRIA";
        Assert.assertEquals(nomeEncontrado, nomeEsperado, "Verificar se a categoria que possuí registros filhos não foi excluída");
    }

}
